@@ -1,7 +1,7 @@
 package GIS::Distance;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 sub new {
     my ($class, $formula, @args) = @_;
@@ -71,7 +71,7 @@ This module calculates distances between geographic points on, at the moment,
 planet Earth.  Various L</FORMULAS> are available that provide different levels
 of accuracy versus speed.
 
-L<GIS::Distance::Fast>, a separate distribution, ships with C implmentations of
+L<GIS::Distance::Fast>, a separate distribution, ships with C implementations of
 some of the formulas shipped with GIS::Distance.  If you're looking for speed
 then install it and the ::Fast formulas will be automatically used by this module.
 
@@ -315,10 +315,14 @@ GIS-Distance GitHub issue tracker:
 
 L<https://github.com/bluefeet/GIS-Distance/issues>
 
-=head1 AUTHORS
+=head1 AUTHOR
 
     Aran Clary Deltac <bluefeet@gmail.com>
+
+=head1 CONTRIBUTORS
+
     Mohammad S Anwar <mohammad.anwar@yahoo.com>
+    Florian Schlichting <fsfs@debian.org>
 
 =head1 LICENSE
 
